export const colorLegend = (
  svg,
  {
    colorScale,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
    tickSpacing = 22,
    tickPadding = 10,
    colorLegendLabelX = -10,
    colorLegendLabelY = -15,
    setHoveredValue,
    hoveredValue,
  },
) => {
  const colorLegendG = svg
    .selectAll('g.color-legend')
    .data([null])
    .join('g')
    .attr('class', 'color-legend')
    .attr(
      'transform',
      `translate(${colorLegendX},${colorLegendY})`,
    );

  colorLegendG
    .selectAll('text.color-legend-label')
    .data([null])
    .join('text')
    .attr('x', colorLegendLabelX)
    .attr('y', colorLegendLabelY)
    .attr('class', 'color-legend-label')
    .attr('font-family', 'sans-serif')
    .text(colorLegendLabel);

  colorLegendG
    .selectAll('g.tick')
    .data(colorScale.domain())
    .join((enter) =>
      enter
        .append('g')
        .attr('class', 'tick')
        .call((svg) => {
          svg.append('circle');
          svg.append('text');
        }),
    )
    .attr(
      'transform',
      (d, i) => `translate(0, ${i * tickSpacing})`,
    )
    .attr('font-size', 10)
    .attr('font-family', 'sans-serif')
    .call((svg) => {
      svg
        .select('circle')
        .attr('r', 8)
        .attr('fill', colorScale);
      svg
        .select('text')
        .attr('dy', '0.32em')
        .attr('x', tickPadding)
        .style('user-select', 'none')
        .text((d) => d);
    })
    .attr('opacity', (d) =>
      hoveredValue ? (d === hoveredValue ? 1 : 0.2) : 1,
    )
    .on('click', (event, d) => {
      setHoveredValue(d);
    })
    .on('dblclick', () => {
      setHoveredValue(null);
    });
};
