import { select } from 'd3';
import { viz } from './viz';
import { data } from '@eschuman20/footballscorers';
import { observeResize } from '@curran/responsive-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;
  const { width, height } = dimensions;

  if (!state.xValue)
    setState((prevState) => ({
      ...prevState,
      xValue: 'Goals',
    }));
  if (!state.yValue)
    setState((prevState) => ({
      ...prevState,
      yValue: 'Shots',
    }));
  if (!state.yearValue)
    setState((prevState) => ({
      ...prevState,
      yearValue: 2016,
    }));

  const yearData = data.filter(
    (d) => d['Year'] === parseInt(state.yearValue),
  );
  const { hoveredValue } = state;
  const setHoveredValue = (d) => {
    setState((state) => ({
      ...state,
      hoveredValue: d,
    }));
  };

  const xSelect = document.createElement('select');
  const ySelect = document.createElement('select');
  const yearSelect = document.createElement('select');

  xSelect.innerHTML = `
    <option value="Goals">Goals</option>
    <option value="Shots">Shots</option>
    <option value="Shots_Per_Avg_Match">Shots Per Match</option>
    <option value="OnTarget">Shots On Target</option>
    <option value="On_Target_Per_Avg_Match">Shots On Target Per Match</option>
    <option value="xG">xG Score</option>
    <option value="xG_Per_Avg_Match">xG Per Match</option>
    <option value="Matches_Played">Matches Played</option>
    <option value="Substitution">Substitutions</option>
    <option value="Mins">Minutes</option>
  `;
  ySelect.innerHTML = `
    <option value="Shots">Shots</option>
    <option value="Goals">Goals</option>
    <option value="Shots_Per_Avg_Match">Shots Per Match</option>
    <option value="OnTarget">Shots On Target</option>
    <option value="On_Target_Per_Avg_Match">Shots On Target Per Match</option>
    <option value="xG">xG Score</option>
    <option value="xG_Per_Avg_Match">xG Per Match</option>
    <option value="Matches_Played">Matches Played</option>
    <option value="Substitution">Substitutions</option>
    <option value="Mins">Minutes</option>
  `;
  yearSelect.innerHTML = `
    <option value=2016>2016</option>
    <option value=2017>2017</option>
    <option value=2018>2018</option>
    <option value=2019>2019</option>
    <option value=2020>2020</option>
  `;

  xSelect.addEventListener('change', () => {
    setState((prevState) => ({
      ...state,
      xValue: xSelect.value,
      yValue: ySelect.value,
      yearValue: yearSelect.value,
    }));
  });

  ySelect.addEventListener('change', () => {
    setState((prevState) => ({
      ...state,
      xValue: xSelect.value,
      yValue: ySelect.value,
      yearValue: yearSelect.value,
    }));
  });

  yearSelect.addEventListener('change', () => {
    setState((prevState) => ({
      ...state,
      xValue: xSelect.value,
      yValue: ySelect.value,
      yearValue: yearSelect.value,
    }));
  });

  container.appendChild(xSelect);
  container.appendChild(ySelect);
  container.appendChild(yearSelect);

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data: yearData,
    xValue: (d) => d[state.xValue],
    xAxisLabelText: state.xValue,
    xAxisLabelOffset: 35,
    yValue: (d) => d[state.yValue],
    yAxisLabelText: state.yValue,
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    circleRadius: 206 / 20,
    circleOpacity: 408 / 1000,
    marginTop: 40,
    marginBottom: 60,
    marginLeft: 54,
    marginRight: 20,
    width,
    height,
    colorLegendX: width - 201,
    colorLegendY: height - 427,
    colorLegendLabel: 'League',
    circleLabel: (d) => d['Player Names'],
    colorValue: (d) => d.League,
    setHoveredValue,
    hoveredValue,
  });
};
