import {
  scaleLinear,
  axisLeft,
  extent,
  select,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { axes } from '@curran/responsive-axes';
import { colorLegend } from './colorLegend';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    circleRadius,
    circleOpacity,
    colorValue,
    circleLabel,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
    setHoveredValue,
    hoveredValue,
  },
) => {
  const xScale = scaleLinear(extent(data, xValue), [
    marginLeft,
    width - marginRight,
  ]);
  const yScale = scaleLinear(extent(data, yValue), [
    height - marginBottom,
    marginTop,
  ]);

  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(schemeCategory10);

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  svg.call(colorLegend, {
    colorScale,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
    setHoveredValue,
    hoveredValue,
  });

  svg
    .selectAll('circle.point')
    .data(data)
    .join('circle')
    .attr('class', 'point')
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)))
    .attr('r', circleRadius)
    .attr('opacity', (d) =>
      hoveredValue
        ? colorValue(d) === hoveredValue
          ? 1
          : 0.2
        : 0.7,
    )
    .attr('fill', (d) => colorScale(colorValue(d)))
    .on('mouseover', function () {
      select(this)
        .transition()
        .attr('r', circleRadius * 2);
      select(this)
        .append('title')
        .text((d) => circleLabel(d));
    })
    .on('mouseout', function () {
      select(this).transition().attr('r', circleRadius);
      select(this).select('title').remove();
    });

  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelText,
    xAxisLabelOffset,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });
};
